@@ -27,7 +27,7 @@ class HttpClientUtils(object):
             headers={'cache-control': "no-cache"},
             method='GET',
             payload=None,
-            verify=True,
+            verify=False,
             proxies=True):
         """
         获取网络对象
@@ -63,7 +63,7 @@ class HttpClientUtils(object):
                 headers={'cache-control': "no-cache"},
                 method='GET',
                 payload=None,
-                verify=True,
+                verify=False,
                 proxies=None):
         """
         网络对象转为文本
@@ -96,8 +96,8 @@ class HttpClientUtils(object):
                   save_file_name=None,
                   ext=None,
                   payload=None,
-                  verify=True):
-        qheader = HttpClientUtils.request_head(url, headers=headers)
+                  verify=False):
+        qheader = HttpClientUtils.request_head(url, headers=headers, verify=verify)
 
         # todo 获取不到文件的大小的问题
         content_length = 0
@@ -159,7 +159,7 @@ class HttpClientUtils(object):
         response = requests.head(url, **kwargs)
         if 'Location' in response.headers:
             if url != response.headers['Location']:
-                return HttpClientUtils.request_head(response.headers['Location'])
+                return HttpClientUtils.request_head(response.headers['Location'], **kwargs)
         return response
 
 
